--------------------------------------------------------------------
-- Script for dialog security sample.
--
-- This file is part of the Microsoft SQL Server Code Samples.
-- Copyright (C) Microsoft Corporation. All Rights reserved.
-- This source code is intended only as a supplement to Microsoft
-- Development Tools and/or on-line documentation. See these other
-- materials for detailed information regarding Microsoft code samples.
--
-- THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF
-- ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
-- THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
-- PARTICULAR PURPOSE.
--------------------------------------------------------------------

-- The target creates a database, queue, service, initiator route,
-- and certificate for the dialog to the initiator service.
-- Modify initiator_host and location of stored certificate in script
-- to suit configuration.

USE master;
GO

-- Create target database.
IF EXISTS (SELECT * FROM sys.databases WHERE name = 'target_database')
	DROP DATABASE target_database;
GO

CREATE DATABASE target_database;
GO

USE target_database;
GO

-- Create a message queue.
CREATE QUEUE target_queue;
GO

-- Create a service with a default contract.
CREATE SERVICE target_service ON QUEUE target_queue ([DEFAULT]);
GO

-- Create a route to the initiator service.
CREATE ROUTE initiator_route
	WITH SERVICE_NAME = 'initiator_service',
	ADDRESS = 'tcp://initiator_host:4022';
GO

-- Create a user who is authorized for the target service.
IF NOT EXISTS (SELECT * FROM sys.sysusers WHERE name = 'target_user')
	CREATE USER target_user WITHOUT LOGIN;
GO

ALTER AUTHORIZATION ON SERVICE::target_service TO target_user;
GO

-- A master key is required to use certificates.
BEGIN TRANSACTION;
IF NOT EXISTS (SELECT * FROM sys.symmetric_keys WHERE name = '##MS_DatabaseMasterKey##')
	CREATE MASTER KEY ENCRYPTION BY PASSWORD='Password#123'
COMMIT;
GO

-- Create a certificate and associate it with the user.
IF EXISTS (SELECT * FROM sys.certificates WHERE name = 'target_dialog_cert')
	DROP CERTIFICATE target_dialog_cert;
GO

CREATE CERTIFICATE target_dialog_cert
	AUTHORIZATION target_user
	WITH SUBJECT = 'Dialog certificate for target';
GO

-- Backup to a file to allow the certificate to be given to the initiator.
BACKUP CERTIFICATE target_dialog_cert
	TO FILE = 'c:\target_dialog.cert';
GO

-- In msdb, create an incoming route to the target service.
USE msdb;
GO

CREATE ROUTE target_route
	WITH SERVICE_NAME = 'target_service',
	ADDRESS = 'local';
GO

USE target_database;
GO

----------EXCHANGE CERTIFICATES BEFORE PROCEEDING---------------
-- The initiator and target certificates must be exchanged in order for them to
-- authenticate each other. In a production system, this "out of band" exchange
-- should be done with a high level of trust, since a certificate bearer will be 
-- able to begin dialogs and send messages to the secured service.However, assuming
-- the sample is being used on a development system, the exchange may be simple
-- remote copies.
